@@ -10,18 +10,21 @@ use switchboard_protos::protos::aggregator_state::mod_AggregatorState;
 use switchboard_protos::protos::fulfillment_manager::FulfillmentManagerState;
 use switchboard_protos::protos::fulfillment_manager::mod_FulfillmentManagerState;
 use switchboard_protos::protos::switchboard_account_types::SwitchboardAccountType;
-use zerocopy::{AsBytes, FromBytes};
 use std::io::Error;
 use std::io::Write;
 use rust_decimal::prelude::Decimal;
 use rust_decimal::prelude::FromPrimitive;
+use bytemuck::{bytes_of_mut, bytes_of};
+use bytemuck::{Pod, Zeroable};
 
-#[derive(Default,AsBytes,FromBytes,Clone,Debug)]
+#[derive(Default,Copy,Clone,Debug)]
 #[repr(C)]
 pub struct SwitchboardDecimal {
     pub mantissa: i128,
     pub scale: u64
 }
+unsafe impl Pod for SwitchboardDecimal {}
+unsafe impl Zeroable for SwitchboardDecimal {}
 
 impl SwitchboardDecimal {
     pub fn from_f64(input: f64) -> Option<Self> {
@@ -39,7 +42,7 @@ impl SwitchboardDecimal {
 
 pub type PubkeyBuffer = [u8; 32];
 
-#[derive(Default,AsBytes,FromBytes,Clone,Debug)]
+#[derive(Default,Copy,Clone,Debug)]
 #[repr(C)]
 pub struct FastRoundResult {
     pub num_success: i32,
@@ -53,18 +56,22 @@ pub struct FastRoundResult {
     // Rust decimal representation of the current result.
     pub decimal: SwitchboardDecimal,
 }
+unsafe impl Pod for FastRoundResult {}
+unsafe impl Zeroable for FastRoundResult {}
 
-#[derive(Default,AsBytes,FromBytes,Clone,Debug)]
+#[derive(Default,Copy,Clone,Debug)]
 #[repr(C)]
 pub struct FastRoundResultAccountData {
     pub parent: PubkeyBuffer,
     // TODO: change name to 'round_result'
     pub result: FastRoundResult,
 }
+unsafe impl Pod for FastRoundResultAccountData {}
+unsafe impl Zeroable for FastRoundResultAccountData {}
 
 impl FastRoundResultAccountData {
     pub fn serialize<W>(&self, writer: &mut W) -> Result<(), Error> where W: Write {
-        let buf = self.as_bytes().to_vec();
+        let buf = bytes_of(self).to_vec();
         let mut res: Vec<u8> = vec![
             SwitchboardAccountType::TYPE_AGGREGATOR_RESULT_PARSE_OPTIMIZED as u8];
         res.extend(buf);
@@ -78,7 +85,7 @@ impl FastRoundResultAccountData {
         }
         let buf = &buf[1..];
         let mut res = FastRoundResultAccountData {..Default::default()};
-        let recv = res.as_bytes_mut();
+        let recv = bytes_of_mut(&mut res);
         if buf.len() < recv.len() {
             return Err(std::io::Error::new(std::io::ErrorKind::InvalidInput, "Invalid buffer length"));
         }
